# xray-rpc

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/laoshan-tech/xray-rpc/Upload%20Python%20Package?style=flat-square)
![GitHub](https://img.shields.io/github/license/laoshan-tech/xray-rpc?style=flat-square)
![GitHub repo size](https://img.shields.io/github/repo-size/laoshan-tech/xray-rpc?style=flat-square)
![PyPI](https://img.shields.io/pypi/v/xray-rpc?color=blue&style=flat-square)
[![Telegram](https://img.shields.io/badge/news-telegram-26A5E4?style=flat-square&logo=telegram)](https://t.me/laoshan_tech)
[![Telegram](https://img.shields.io/badge/chat-telegram-26A5E4?style=flat-square&logo=telegram)](https://t.me/laoshan_tech_discuss)

通过 Xray 源码 proto 文件自动生成的 gRPC 代码，版本号对应 Xray 相对应。

## 安装

通过 pip 安装。

```shell
pip install xray-rpc
```

## 使用

参考 [xray-node](https://github.com/laoshan-tech/xray-node/blob/master/xray_node/core/xray.py) 中的用法。